import json
import yaml

def open_yaml(file_path, file_name):
    yaml_file=file_path + file_name
    with open(yaml_file) as openfile:
        yaml_object=yaml.load(openfile,Loader=yaml.FullLoader)
        return yaml_object # retourne un dictionnaire


def open_json(file_path, file_name):
    
    json_file=file_path + file_name
    
    with open(json_file,'r') as openfile:
        json_object=json.load(openfile)
        return json_object

        

def save_yaml(path, decoded_dictionary, yaml_file_name):
    
    yaml_file= path + yaml_file_name
    
    with open (yaml_file, "w") as outfile:
        yaml.dump(decoded_dictionary, outfile, default_flow_style=False)

def save_json(path, decoded_dictionary, json_file_name):
    
    my_file= path + json_file_name
    with open(my_file, "w") as outfile:
        json.dump(decoded_dictionary, outfile, indent=2)




import qrcode
import cv2
import json

from cfg2qr import file_manip


def check_file_type(file_name):



    _, ext = file_name.split(".")

    return ext #type str

    



def encode(path,input_file,image_save):

    

    if check_file_type(input_file)=='json': 

        input_dictionary=file_manip.open_json(path, input_file)

    elif check_file_type(input_file)=='yaml':

        input_dictionary=file_manip.open_yaml(path, input_file)

    else: 

        print("problem reading file")

    

    input_text = json.dumps(input_dictionary)

    img = qrcode.make(input_text)

    type(img)  # qrcode.image.pil.PilImage

    file_path=path + image_save
    img.save(file_path)



def decode(path, image_file,decoded_file):

    file_path=path + image_file

    image = cv2.imread(file_path)

    qrCodeDetector = cv2.QRCodeDetector()

    

    decoded_text, points, _ = qrCodeDetector.detectAndDecode(image)

    points = points.astype(int)

    

    result_dict=json.loads(decoded_text)

    

    if points is not None:

        # QR Code detected handling code

        if check_file_type(decoded_file)=='json': 

            file_manip.save_json(path, result_dict,decoded_file)

        elif check_file_type(decoded_file)=='yaml':

            file_manip.save_yaml(path, result_dict,decoded_file)

        else: 

            print("Problem saving file")

            

    else:

        print("QR code not detected")



from pathlib import Path
from setuptools import setup, find_packages

#The directory containing this file
HERE = Path(__file__).parent

#The text of the README file
README = (HERE/ "README.md").read_text()

#The text of the instal requirements
def list_reqs(fname='requirements.txcdt'):
    with open(fname) as fd:
        return fd.read().splitlines()

INSTALL_REQUIRES = list_reqs(fname='requirements.txt')

#meta-data
setup(
    name='cfg2qr',
    version='0.1.7',
    license='MIT',
    author="Kristina",
    description = "Small personal project to learn about Python packaging.",
    long_description=README,
    long_description_content_type='text/markdown',
    # author_email='email@example.com',
    # package_dir={"": "cfg2qr"},
    packages=find_packages(),
    url='https://github.com/kristin54/qr-code',
    keywords='qr-code project',
    install_requires=INSTALL_REQUIRES,
    entry_points={
        'console_scripts': ['cfg2qr=cfg2qr.main:main'],
    },
    classifiers=[
        # Trove classifiers
        # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3 :: Only'
    ]

)

# #Laurent Boucaud
# entry_points={
#         'console_scripts': ['qr2png=qr2png.main:main'],
#     }


import argparse
from cfg2qr import qr_transformations



def main():

    # Create parser and subparser
    parser = argparse.ArgumentParser()
    subparser = parser.add_subparsers(dest='command')
    encoder = subparser.add_parser('encoder')
    decoder = subparser.add_parser('decoder') 

    #Add parser argument for input and result files path
    parser.add_argument(
        '--input_directory',
        type=str,
        required = True
    )


    
    #Add subparser encoder argument: file path to be encoded
    encoder.add_argument(
        '-input_text_name',
        type=str,
        required = True
    )

     #Add subparser encoder argument: encoded images
    encoder.add_argument(
        '-result_image_name',
        type=str,
        required = True
    )

    #Add subparser decoder argument:file path to be decoded
    decoder.add_argument(
        '-input_image_name',
        type=str,
        required=True
    )

    #Add subparser decoder argument:file path to be decoded
    decoder.add_argument(
        '-result_text_name',
        type=str,
        required=True
    )
  
    # Parse the argument
    args = parser.parse_args()


    if args.command == 'encoder':
        qr_transformations.encode(args.input_directory, args.input_text_name, args.result_image_name)
        print("Encoded QR code saved.")
    elif args.command == 'decoder':
        qr_transformations.decode(args.input_directory, args.input_image_name, args.result_text_name)
        print("Decoded text saved.")



if __name__ == "__main__":
    main()
    #print(type(open_yaml("data/","text2.yaml")))
    #python poupou.py --result_file './data/decoded_text.json' decoder -image_file './data/img_test_15.png'